<?php

/**
 * @file
 * This is a quick prototype of a localized Drupal installer.
 *
 * Still needs more testing and development.
 */

/**
 * Implementation of hook_profile_details().
 */
function l10n_install_profile_details() {
  return array(
    'name' => 'Localized Drupal',
    'description' => 'Localized Drupal installation using data from localize.drupal.org'
  );
}

/**
 * Implementation of hook_profile_modules().
 */
function l10n_install_profile_modules() {
  $modules = array('color', 'comment', 'help', 'menu', 'taxonomy', 'dblog', 'locale', 'l10n_client', 'l10n_update');
  return $modules;
}

/**
 * Implementation of hook_profile_task_list().
 */
function l10n_install_profile_task_list() {
  $tasks = array();
  if (_l10n_install_language_selected()) {
    $tasks['l10n-install-batch'] = st('Download and import translations');
  }
  return $tasks;
}

/**
 * Implementation of hook_profile_tasks().
 */
function l10n_install_profile_tasks(&$task, $url) {
  global $install_locale;

  // Download and import translations if needed.
  if ($task == 'profile') {
    // Perform the default profile install tasks.
    include_once('profiles/default/default.profile');
    default_profile_tasks($task, $url);
    // Move forward to our install batch.
    $task = 'l10n-install';
  }

  if ($task == 'l10n-install') {
    if (_l10n_install_language_selected()) {
      $history = l10n_update_get_history();
      module_load_include('check.inc', 'l10n_update');
      $available = l10n_update_available_releases();
      $updates = l10n_update_build_updates($history, $available);

      module_load_include('batch.inc', 'l10n_update');
      $updates = _l10n_update_prepare_updates($updates, NULL, array());
      $batch = l10n_update_batch_multiple($updates, LOCALE_IMPORT_KEEP);

      // Overwrite batch finish callback, so we can modify install task too.
      $batch['finished'] = '_l10n_install_batch_finished';

      // Start a batch, switch to 'l10n-install-batch' task. We need to
      // set the variable here, because batch_process() redirects.
      variable_set('install_task', 'l10n-install-batch');
      batch_set($batch);
      batch_process($url, $url);
    }
  }

  if ($task == 'l10n-install-batch') {
    include_once 'includes/batch.inc';
    return _batch_page();
  }
}

/**
 * Implementation of hook_form_alter().
 */
function l10n_install_form_alter(&$form, $form_state, $form_id) {
  if ($form_id == 'install_configure') {
    // Set default for site name field.
    $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
  }
}

/**
 * Check whether we are installing in a language other than English.
 */
function _l10n_install_language_selected() {
  global $install_locale;
  return !empty($install_locale) && ($install_locale != 'en');
}

/**
 * Batch finish callback for l10n_install batches.
 */
function _l10n_install_batch_finished($success, $results) {
  if ($success) {
    variable_set('install_task', 'profile-finished');
  }
  // Invoke default batch finish function too.
  module_load_include('batch.inc', 'l10n_update');
  _l10n_update_batch_finished($success, $results);

  // Set up l10n_client and inform the admin about it.
  // @todo This message will not show up for some reason.
  global $user;
  variable_set('l10n_client_use_server', 1);
  variable_set('l10n_client_server', 'http://localize.drupal.org');
  drupal_set_message(t('Localization client is set up to share your translations with <a href="@localize">localize.drupal.org</a>. Each participating user should have a localize.drupal.org account and set up their API key on their user profile page. <a href="@edit-profile">Set up yours</a>.', array('@localize' => 'http://localize.drupal.org', '@edit-profile' => url('user/' . $user->uid . '/edit'))));
}
